Documentation
¶
Overview ¶
Package proto is a generated protocol buffer package.
It is generated from these files:
collectd.proto
It has these top-level messages:
PutValuesRequest PutValuesResponse QueryValuesRequest QueryValuesResponse
Index ¶
- func RegisterCollectdServer(s *grpc.Server, srv CollectdServer)
- type CollectdClient
- type CollectdServer
- type Collectd_PutValuesClient
- type Collectd_PutValuesServer
- type Collectd_QueryValuesClient
- type Collectd_QueryValuesServer
- type PutValuesRequest
- type PutValuesResponse
- type QueryValuesRequest
- type QueryValuesResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterCollectdServer ¶
func RegisterCollectdServer(s *grpc.Server, srv CollectdServer)
Types ¶
type CollectdClient ¶
type CollectdClient interface {
// PutValues reads the value lists from the PutValuesRequest stream.
// The gRPC server embedded into collectd will inject them into the system
// just like the network plugin.
PutValues(ctx context.Context, opts ...grpc.CallOption) (Collectd_PutValuesClient, error)
// QueryValues returns a stream of matching value lists from collectd's
// internal cache.
QueryValues(ctx context.Context, in *QueryValuesRequest, opts ...grpc.CallOption) (Collectd_QueryValuesClient, error)
}
func NewCollectdClient ¶
func NewCollectdClient(cc *grpc.ClientConn) CollectdClient
type CollectdServer ¶
type CollectdServer interface {
// PutValues reads the value lists from the PutValuesRequest stream.
// The gRPC server embedded into collectd will inject them into the system
// just like the network plugin.
PutValues(Collectd_PutValuesServer) error
// QueryValues returns a stream of matching value lists from collectd's
// internal cache.
QueryValues(*QueryValuesRequest, Collectd_QueryValuesServer) error
}
type Collectd_PutValuesClient ¶
type Collectd_PutValuesClient interface {
Send(*PutValuesRequest) error
CloseAndRecv() (*PutValuesResponse, error)
grpc.ClientStream
}
type Collectd_PutValuesServer ¶
type Collectd_PutValuesServer interface {
SendAndClose(*PutValuesResponse) error
Recv() (*PutValuesRequest, error)
grpc.ServerStream
}
type Collectd_QueryValuesClient ¶
type Collectd_QueryValuesClient interface {
Recv() (*QueryValuesResponse, error)
grpc.ClientStream
}
type Collectd_QueryValuesServer ¶
type Collectd_QueryValuesServer interface {
Send(*QueryValuesResponse) error
grpc.ServerStream
}
type PutValuesRequest ¶
type PutValuesRequest struct {
// value_list is the metric to be sent to the server.
ValueList *collectd_types.ValueList `protobuf:"bytes,1,opt,name=value_list,json=valueList" json:"value_list,omitempty"`
}
The arguments to PutValues.
func (*PutValuesRequest) Descriptor ¶
func (*PutValuesRequest) Descriptor() ([]byte, []int)
func (*PutValuesRequest) GetValueList ¶
func (m *PutValuesRequest) GetValueList() *collectd_types.ValueList
func (*PutValuesRequest) ProtoMessage ¶
func (*PutValuesRequest) ProtoMessage()
func (*PutValuesRequest) Reset ¶
func (m *PutValuesRequest) Reset()
func (*PutValuesRequest) String ¶
func (m *PutValuesRequest) String() string
type PutValuesResponse ¶
type PutValuesResponse struct {
}
The response from PutValues.
func (*PutValuesResponse) Descriptor ¶
func (*PutValuesResponse) Descriptor() ([]byte, []int)
func (*PutValuesResponse) ProtoMessage ¶
func (*PutValuesResponse) ProtoMessage()
func (*PutValuesResponse) Reset ¶
func (m *PutValuesResponse) Reset()
func (*PutValuesResponse) String ¶
func (m *PutValuesResponse) String() string
type QueryValuesRequest ¶
type QueryValuesRequest struct {
// Query by the fields of the identifier. Only return values matching the
// specified shell wildcard patterns (see fnmatch(3)). Use '*' to match
// any value.
Identifier *collectd_types.Identifier `protobuf:"bytes,1,opt,name=identifier" json:"identifier,omitempty"`
}
The arguments to QueryValues.
func (*QueryValuesRequest) Descriptor ¶
func (*QueryValuesRequest) Descriptor() ([]byte, []int)
func (*QueryValuesRequest) GetIdentifier ¶
func (m *QueryValuesRequest) GetIdentifier() *collectd_types.Identifier
func (*QueryValuesRequest) ProtoMessage ¶
func (*QueryValuesRequest) ProtoMessage()
func (*QueryValuesRequest) Reset ¶
func (m *QueryValuesRequest) Reset()
func (*QueryValuesRequest) String ¶
func (m *QueryValuesRequest) String() string
type QueryValuesResponse ¶
type QueryValuesResponse struct {
ValueList *collectd_types.ValueList `protobuf:"bytes,1,opt,name=value_list,json=valueList" json:"value_list,omitempty"`
}
The response from QueryValues.
func (*QueryValuesResponse) Descriptor ¶
func (*QueryValuesResponse) Descriptor() ([]byte, []int)
func (*QueryValuesResponse) GetValueList ¶
func (m *QueryValuesResponse) GetValueList() *collectd_types.ValueList
func (*QueryValuesResponse) ProtoMessage ¶
func (*QueryValuesResponse) ProtoMessage()
func (*QueryValuesResponse) Reset ¶
func (m *QueryValuesResponse) Reset()
func (*QueryValuesResponse) String ¶
func (m *QueryValuesResponse) String() string
Click to show internal directories.
Click to hide internal directories.